@@ -144,7 +144,7 @@ KsMainWindow::KsMainWindow(QWidget *parent)
 	connect(&_plugins,	&KsPluginManager::dataReload,
 		&_data,		&KsDataStore::reload);
 
-	_deselectShortcut.setKey(Qt::CTRL + Qt::Key_D);
+	_deselectShortcut.setKey(Qt::CTRL | Qt::Key_D);
 	connect(&_deselectShortcut,	&QShortcut::activated,
 		this,			&KsMainWindow::_deselectActive);
 
@@ -1275,7 +1275,7 @@ void KsMainWindow::_load(const QString& fileName, bool append)
 		pbLabel += fileName;
 	} else {
 		pbLabel += "...";
-		pbLabel += fileName.mid(fileName.size() - 37, 37);
+		pbLabel += fileName.sliced(fileName.size() - 37);
 	}
 
 	setWindowTitle("Kernel Shark");
@@ -1434,12 +1434,12 @@ void KsMainWindow::loadSession(const QString &fileName)
 	_session.loadUserPlugins(kshark_ctx, &_plugins);
 	pb.setValue(20);
 
-	auto lamLoadJob = [&] (KsDataStore *d) {
+	auto lamLoadJob = [&] () {
 		_session.loadDataStreams(kshark_ctx, &_data);
 		loadDone = true;
 	};
 
-	std::thread job = std::thread(lamLoadJob, &_data);
+	std::thread job = std::thread(lamLoadJob);
 
 	for (int i = 0; i < 150; ++i) {
 		/*
@@ -1502,12 +1502,8 @@ void KsMainWindow::_initCapture()
 	connect(&_capture,	&QProcess::started,
 		this,		&KsMainWindow::_captureStarted);
 
-	/*
-	 * Using the old Signal-Slot syntax because QProcess::finished has
-	 * overloads.
-	 */
-	connect(&_capture,	SIGNAL(finished(int, QProcess::ExitStatus)),
-		this,		SLOT(_captureFinished(int, QProcess::ExitStatus)));
+	connect(&_capture,	&QProcess::finished,
+		this,		&KsMainWindow::_captureFinished);
 
 	_captureErrorConnection =
 		connect(&_capture,	&QProcess::errorOccurred,
@@ -1548,9 +1544,9 @@ void KsMainWindow::_captureFinished(int ret, QProcess::ExitStatus st)
 		_captureErrorMessage(capture);
 }
 
-void KsMainWindow::_captureError(QProcess::ProcessError error)
+void KsMainWindow::_captureError([[maybe_unused]] QProcess::ProcessError error)
 {
-	QProcess *capture = (QProcess *)sender();
+	QProcess *capture = static_cast<QProcess*>(sender());
 	_captureErrorMessage(capture);
 }
 
@@ -1599,7 +1595,8 @@ void KsMainWindow::_readSocket()
 	loadDataFile(fileName);
 }
 
-void KsMainWindow::_splitterMoved(int pos, int index)
+void KsMainWindow::_splitterMoved([[maybe_unused]] int pos,
+				  [[maybe_unused]] int index)
 {
 	_session.saveSplitterSize(_splitter);
 }
