@@ -331,7 +331,6 @@ void KsTraceGraph::_setPointerInfo(size_t i)
 	QString aux(lanMakeString(kshark_get_aux_info(e)));
 	QString info(lanMakeString(kshark_get_info(e)));
 	QString comm(lanMakeString(kshark_get_task(e)));
-	QString elidedText;
 	int labelWidth;
 	uint64_t sec, usec;
 	char *pointer;
@@ -594,8 +593,8 @@ void KsTraceGraph::updateGeom()
 	       _layout.contentsMargins().top() +
 	       _layout.contentsMargins().bottom();
 
-	if (hMin > KS_GRAPH_HEIGHT * 8)
-		hMin = KS_GRAPH_HEIGHT * 8;
+	if (hMin > KS_GRAPH_HEIGHT * 6)
+		hMin = KS_GRAPH_HEIGHT * 6;
 
 	setMinimumHeight(hMin);
 
@@ -614,14 +613,14 @@ void KsTraceGraph::updateGeom()
 			       * widget is extended to maximum.
 			       */
 
-	_glWindow.update();
+	_glWindow.updateGeom();
 }
 
 /**
  * Reimplemented event handler used to update the geometry of the widget on
  * resize events.
  */
-void KsTraceGraph::resizeEvent(QResizeEvent* event)
+void KsTraceGraph::resizeEvent([[maybe_unused]] QResizeEvent* event)
 {
 	updateGeom();
 }
