@@ -324,7 +324,7 @@ QCheckBox *addCheckBoxToMenu(QMenu *menu, QString name)
  * @returns True if the CPU of the entry matches the value of "cpu" and
  * 	    the entry is visibility in Graph. Otherwise false.
  */
-bool matchCPUVisible(struct kshark_context *kshark_ctx,
+bool matchCPUVisible([[maybe_unused]] struct kshark_context *kshark_ctx,
 		     struct kshark_entry *e, int sd, int *cpu)
 {
 	return (e->cpu == *cpu &&
@@ -471,7 +471,7 @@ QString getSaveFile(QWidget *parent,
 	if (!fileName.isEmpty() && !fileName.endsWith(extension)) {
 		fileName += extension;
 
-		if (QFileInfo(fileName).exists()) {
+		if (QFileInfo::exists(fileName)) {
 			if (!KsWidgetsLib::fileExistsDialog(fileName))
 				fileName.clear();
 		}
@@ -489,12 +489,12 @@ QStringList splitArguments(QString cmd)
 	auto opt = KS_SPLIT_SkipEmptyParts;
 	int i, progress = 0, size;
 	QStringList argv;
-	QChar quote = 0;
+	QChar quote{'\0'};
 
 	/* Remove all new lines. */
 	cmd.replace("\\\n", " ");
 
-	size = cmd.count();
+	size = cmd.size();
 	auto lamMid = [&] () {return cmd.mid(progress, i - progress);};
 	for (i = 0; i < size; ++i) {
 		if (cmd[i] == '\\') {
@@ -510,7 +510,7 @@ QStringList splitArguments(QString cmd)
 				progress = i;
 			} else if (quote == cmd[i]) {
 				argv << lamMid();
-				quote = 0;
+				quote = {'\0'};
 				progress = ++i;
 			}
 		}
@@ -530,12 +530,12 @@ QVector<int> parseIdList(QString v_str)
 	QStringList list = v_str.split(",", KS_SPLIT_SkipEmptyParts);
 	QVector<int> v;
 
-	for (auto item: list) {
+	for (const auto &item: list) {
 		int i = item.indexOf('-');
 		if (i > 0) {
 			/* This item is an interval. */
-			int to = item.right(item.size() - i - 1).toInt();
-			int from = item.left(i).toInt();
+			int to = item.sliced(i + 1).toInt();
+			int from = item.first(i).toInt();
 			int s = v.size();
 
 			v.resize(s + to - from + 1);
@@ -1414,7 +1414,6 @@ void KsPluginManager::updatePlugins(int sd, QVector<int> pluginStates)
 	kshark_context *kshark_ctx(nullptr);
 	kshark_data_stream *stream;
 	kshark_dpi_list *plugin;
-	QVector<int> vec;
 	int i(0);
 
 	if (!kshark_instance(&kshark_ctx))
