@@ -123,12 +123,6 @@ public:
 	explicit KsDataWidget(QWidget *parent = nullptr)
 	: QWidget(parent), _workInProgress(nullptr) {}
 
-	/** Set a pointer to the KsWorkInProgress widget. */
-	const KsWorkInProgress *wipPtr(KsWorkInProgress *wip) const
-	{
-		return _workInProgress;
-	}
-
 	/** Set the pointer to the KsWorkInProgress widget. */
 	void setWipPtr(KsWorkInProgress *wip)
 	{
@@ -261,20 +255,21 @@ public:
 	 */
 	int sd() const {return _sd;}
 
+	/** The user provided an input. The widget has been modified. */
+	bool _userInput;
+
+protected:
 	/**
 	 * Reimplemented event handler used to update the geometry of the widget on
 	 * resize events.
 	 */
-	void resizeEvent(QResizeEvent* event)
+	void resizeEvent([[maybe_unused]] QResizeEvent* event) override
 	{
 		KsUtils::setElidedText(&_streamLabel, _streamName,
 				       Qt::ElideLeft, width());
 		QApplication::processEvents();
 	}
 
-	/** The user provided an input. The widget has been modified. */
-	bool _userInput;
-
 protected:
 	QToolBar _tb;
 
@@ -635,9 +630,9 @@ public:
 	void setStreamCombo();
 
 private slots:
-	void _streamChanged(const QString &stream);
+	void _streamChanged(int);
 
-	void _eventChanged(const QString &event);
+	void _eventChanged(int);
 
 private:
 	QVBoxLayout	_topLayout;
