@@ -121,6 +121,8 @@ static void kshark_stream_free(struct kshark_data_stream *stream)
 	if (!stream)
 		return;
 
+	kshark_hash_id_free(stream->idle_cpus);
+
 	kshark_hash_id_free(stream->show_task_filter);
 	kshark_hash_id_free(stream->hide_task_filter);
 
@@ -147,6 +149,8 @@ static struct kshark_data_stream *kshark_stream_alloc()
 	if (!stream)
 		goto fail;
 
+	stream->idle_cpus = kshark_hash_id_alloc(KS_FILTER_HASH_NBITS);
+
 	stream->show_task_filter = kshark_hash_id_alloc(KS_FILTER_HASH_NBITS);
 	stream->hide_task_filter = kshark_hash_id_alloc(KS_FILTER_HASH_NBITS);
 
@@ -433,6 +437,8 @@ static int kshark_stream_close(struct kshark_data_stream *stream)
 	kshark_hash_id_clear(stream->show_cpu_filter);
 	kshark_hash_id_clear(stream->hide_cpu_filter);
 
+	kshark_hash_id_clear(stream->idle_cpus);
+
 	if (kshark_is_tep(stream))
 		return kshark_tep_close_interface(stream);
 
@@ -1364,14 +1370,15 @@ void kshark_clear_all_filters(struct kshark_context *kshark_ctx,
 			      size_t n_entries)
 {
 	struct kshark_data_stream *stream;
-	int *stream_ids, i;
+	int *stream_ids, sd;
+	size_t i;
 
 	for (i = 0; i < n_entries; ++i)
 		set_all_visible(&data[i]->visible);
 
 	stream_ids = kshark_all_streams(kshark_ctx);
-	for (i = 0; i < kshark_ctx->n_streams; i++) {
-		stream = kshark_get_data_stream(kshark_ctx, stream_ids[i]);
+	for (sd = 0; sd < kshark_ctx->n_streams; sd++) {
+		stream = kshark_get_data_stream(kshark_ctx, stream_ids[sd]);
 		stream->filter_is_applied = false;
 	}
 
@@ -1566,7 +1573,7 @@ ssize_t kshark_find_entry_by_time(int64_t time,
  * @returns True if the Pid of the entry matches the value of "pid".
  *	    Else false.
  */
-bool kshark_match_pid(struct kshark_context *kshark_ctx,
+bool kshark_match_pid(__attribute__ ((unused)) struct kshark_context *kshark_ctx,
 		      struct kshark_entry *e, int sd, int *pid)
 {
 	if (e->stream_id == sd && e->pid == *pid)
@@ -1586,7 +1593,7 @@ bool kshark_match_pid(struct kshark_context *kshark_ctx,
  * @returns True if the Cpu of the entry matches the value of "cpu".
  *	    Else false.
  */
-bool kshark_match_cpu(struct kshark_context *kshark_ctx,
+bool kshark_match_cpu(__attribute__ ((unused)) struct kshark_context *kshark_ctx,
 		      struct kshark_entry *e, int sd, int *cpu)
 {
 	if (e->stream_id == sd && e->cpu == *cpu)
@@ -1606,7 +1613,7 @@ bool kshark_match_cpu(struct kshark_context *kshark_ctx,
  * @returns True if the event Id of the entry matches the value of "event_id".
  *	    Else false.
  */
-bool kshark_match_event_id(struct kshark_context *kshark_ctx,
+bool kshark_match_event_id(__attribute__ ((unused)) struct kshark_context *kshark_ctx,
 			   struct kshark_entry *e, int sd, int *event_id)
 {
 	return e->stream_id == sd && e->event_id == *event_id;
@@ -1624,7 +1631,7 @@ bool kshark_match_event_id(struct kshark_context *kshark_ctx,
  * @returns True if the event Id of the entry matches the values.
  *	    Else false.
  */
-bool kshark_match_event_and_pid(struct kshark_context *kshark_ctx,
+bool kshark_match_event_and_pid(__attribute__ ((unused)) struct kshark_context *kshark_ctx,
 				struct kshark_entry *e,
 				int sd, int *values)
 {
@@ -1645,7 +1652,7 @@ bool kshark_match_event_and_pid(struct kshark_context *kshark_ctx,
  * @returns True if the event Id of the entry matches the values.
  *	    Else false.
  */
-bool kshark_match_event_and_cpu(struct kshark_context *kshark_ctx,
+bool kshark_match_event_and_cpu(__attribute__ ((unused)) struct kshark_context *kshark_ctx,
 				struct kshark_entry *e,
 				int sd, int *values)
 {
@@ -1896,10 +1903,13 @@ void kshark_set_clock_offset(struct kshark_context *kshark_ctx,
 	kshark_data_qsort(entries, size);
 }
 
-static int first_in_time_entry(struct kshark_entry_data_set *buffer, int n_buffers, size_t *count)
+static int first_in_time_entry(struct kshark_entry_data_set *buffer,
+			       size_t n_buffers,
+			       ssize_t *count)
 {
 	int64_t t_min = INT64_MAX;
-	int i, min = -1;
+	int min = -1;
+	size_t i;
 
 	for (i = 0; i < n_buffers; ++i) {
 		if (count[i] == buffer[i].n_rows)
@@ -1924,10 +1934,11 @@ static int first_in_time_entry(struct kshark_entry_data_set *buffer, int n_buffe
  *	    responsible for freeing the elements of the outputted array.
  */
 struct kshark_entry **
-kshark_merge_data_entries(struct kshark_entry_data_set *buffers, int n_buffers)
+kshark_merge_data_entries(struct kshark_entry_data_set *buffers, size_t n_buffers)
 {
 	struct kshark_entry **merged_data;
-	size_t i, tot = 0, count[n_buffers];
+	ssize_t count[n_buffers];
+	size_t i, tot = 0;
 	int i_first;
 
 	if (n_buffers < 2) {
@@ -2072,7 +2083,9 @@ ssize_t kshark_append_all_entries(struct kshark_context *kshark_ctx,
 				merged_data);
 }
 
-static int first_in_time_row(struct kshark_matrix_data_set *buffers, int n_buffers, size_t *count)
+static int first_in_time_row(struct kshark_matrix_data_set *buffers,
+			     int n_buffers,
+			     ssize_t *count)
 {
 	int64_t t_min = INT64_MAX;
 	int i, min = -1;
@@ -2101,10 +2114,11 @@ static int first_in_time_row(struct kshark_matrix_data_set *buffers, int n_buffe
  *	    matrix.
  */
 struct kshark_matrix_data_set
-kshark_merge_data_matrices(struct kshark_matrix_data_set *buffers, int n_buffers)
+kshark_merge_data_matrices(struct kshark_matrix_data_set *buffers, size_t n_buffers)
 {
 	struct kshark_matrix_data_set merged_data;
-	size_t i, tot = 0, count[n_buffers];
+	ssize_t count[n_buffers];
+	size_t i, tot = 0;
 	int i_first;
 	bool status;
 
