@@ -12,14 +12,14 @@
 #include "libkshark-plugin.h"
 
 /** Load this plugin. */
-int KSHARK_PLOT_PLUGIN_INITIALIZER(struct kshark_data_stream *stream)
+int KSHARK_PLOT_PLUGIN_INITIALIZER(__attribute__ ((unused)) struct kshark_data_stream *stream)
 {
 	printf("--> plugin1\n");
 	return 1;
 }
 
 /** Unload this plugin. */
-int KSHARK_PLOT_PLUGIN_DEINITIALIZER(struct kshark_data_stream *stream)
+int KSHARK_PLOT_PLUGIN_DEINITIALIZER(__attribute__ ((unused)) struct kshark_data_stream *stream)
 {
 	printf("<-- plugin1\n");
 	return 1;
